pub enum CodeType {
StandardPlanarCode,
RotatedPlanarCode,
StandardXZZXCode,
RotatedXZZXCode,
StandardTailoredCode,
RotatedTailoredCode,
RotatedTailoredCodeBellInit,
PeriodicRotatedTailoredCode,
Customized,
}Expand description
commonly used code type that has built-in functions to automatically build up the simulator. other type of code type is also feasible, but one needs to implement the generation of code patch.
Variants
StandardPlanarCode
noisy measurement rounds (excluding the final perfect measurement cap), vertical code distance, horizontal code distance
RotatedPlanarCode
noisy measurement rounds (excluding the final perfect measurement cap), +i+j axis code distance, +i-j axis code distance
StandardXZZXCode
noisy measurement rounds (excluding the final perfect measurement cap), vertical code distance, horizontal code distance
RotatedXZZXCode
noisy measurement rounds (excluding the final perfect measurement cap), +i+j axis code distance, +i-j axis code distance
StandardTailoredCode
noisy measurement rounds (excluding the final perfect measurement cap), vertical code distance, horizontal code distance
RotatedTailoredCode
noisy measurement rounds (excluding the final perfect measurement cap), +i+j axis code distance, +i-j axis code distance
RotatedTailoredCodeBellInit
same as RotatedTailoredCode but with first measurement cycle modified for bell state initialization
PeriodicRotatedTailoredCode
periodic boundary condition of rotated tailored surface code, code distances must be even number
Customized
unknown code type, user must provide necessary information and build circuit-level implementation
Implementations
Sourceimpl CodeType
impl CodeType
Sourcepub fn get_left(
&self,
i: usize,
j: usize,
code_size: &CodeSize,
) -> (usize, usize)
pub fn get_left( &self, i: usize, j: usize, code_size: &CodeSize, ) -> (usize, usize)
get position on the left of (i, j), note that this position may be invalid for open-boundary code if it doesn’t exist
Sourcepub fn get_up(&self, i: usize, j: usize, code_size: &CodeSize) -> (usize, usize)
pub fn get_up(&self, i: usize, j: usize, code_size: &CodeSize) -> (usize, usize)
get position up the position (i, j), note that this position may be invalid for open-boundary code if it doesn’t exist
Sourcepub fn get_right(
&self,
i: usize,
j: usize,
code_size: &CodeSize,
) -> (usize, usize)
pub fn get_right( &self, i: usize, j: usize, code_size: &CodeSize, ) -> (usize, usize)
get position on the right of (i, j), note that this position may be invalid for open-boundary code if it doesn’t exist
Sourcepub fn get_down(
&self,
i: usize,
j: usize,
code_size: &CodeSize,
) -> (usize, usize)
pub fn get_down( &self, i: usize, j: usize, code_size: &CodeSize, ) -> (usize, usize)
get position down the position (i, j), note that this position may be invalid for open-boundary code if it doesn’t exist
Sourcepub fn get_left_up(
&self,
i: usize,
j: usize,
code_size: &CodeSize,
) -> (usize, usize)
pub fn get_left_up( &self, i: usize, j: usize, code_size: &CodeSize, ) -> (usize, usize)
convenient call to get diagonal neighbor on the left up
Sourcepub fn get_left_down(
&self,
i: usize,
j: usize,
code_size: &CodeSize,
) -> (usize, usize)
pub fn get_left_down( &self, i: usize, j: usize, code_size: &CodeSize, ) -> (usize, usize)
convenient call to get diagonal neighbor on the left down