pub struct MWPMDecoder {
pub model_graph: Arc<ModelGraph>,
pub erasure_graph: Arc<ErasureGraph>,
pub complete_model_graph: CompleteModelGraph,
pub config: MWPMDecoderConfig,
pub simulator: Arc<Simulator>,
}Expand description
MWPM decoder, initialized and cloned for multiple threads
Fields
model_graph: Arc<ModelGraph>model graph is immutably shared
erasure_graph: Arc<ErasureGraph>erasure graph is immutably shared
complete_model_graph: CompleteModelGraphcomplete model graph each thread maintain its own precomputed data; the internal model_graph might be copied and modified if erasure error exists
config: MWPMDecoderConfigsave configuration for later usage
simulator: Arc<Simulator>an immutably shared simulator that is used to change model graph on the fly for correcting erasure errors
Implementations
Sourceimpl MWPMDecoder
impl MWPMDecoder
Sourcepub fn new(
simulator: &Simulator,
noise_model: Arc<NoiseModel>,
decoder_configuration: &Value,
parallel: usize,
use_brief_edge: bool,
) -> Self
pub fn new( simulator: &Simulator, noise_model: Arc<NoiseModel>, decoder_configuration: &Value, parallel: usize, use_brief_edge: bool, ) -> Self
create a new MWPM decoder with decoder configuration
Sourcepub fn decode(
&mut self,
sparse_measurement: &SparseMeasurement,
) -> (SparseCorrection, Value)
pub fn decode( &mut self, sparse_measurement: &SparseMeasurement, ) -> (SparseCorrection, Value)
decode given measurement results
Sourcepub fn decode_with_erasure(
&mut self,
sparse_measurement: &SparseMeasurement,
sparse_detected_erasures: &SparseErasures,
) -> (SparseCorrection, Value)
pub fn decode_with_erasure( &mut self, sparse_measurement: &SparseMeasurement, sparse_detected_erasures: &SparseErasures, ) -> (SparseCorrection, Value)
decode given measurement results and detected erasures